Module config

Module config 

Structs

Config
SiteConfig
TlsConfig
TLS configuration for a site — paths to certificate chain and private key.

Enums

Directive

Functions

extract_hostname
Extract the hostname portion from an address string (used as SNI key).
resolve_listen_addr
Resolve a config address string to a SocketAddr suitable for binding.
tls_redirect_port
HTTP port for redirect listeners derived from the TLS listen port.