Structs
- Config
- Site
Config - TlsConfig
- TLS configuration for a site — paths to certificate chain and private key.
Enums
Functions
- extract_
hostname - Extract the hostname portion from an address string (used as SNI key).
- resolve_
listen_ addr - Resolve a config address string to a
SocketAddrsuitable for binding. - tls_
redirect_ port - HTTP port for redirect listeners derived from the TLS listen port.